@@ -7,7 +7,7 @@ namespace LAC {
     struct Manhattan : public Base<T> {
       typedef typename Base<T>::va_t va_t;
       T Diff(const va_t& a, const va_t& b) const {
-	return abs(a - b).sum();
+	return std::abs(a - b).sum();
       }
       Base<T>* Clone() const { return new Manhattan; }
     };
